django-valet-keys is a Django app for managing valet keys to let robots drive
around in your identity.

- `Build status on travis-ci <http://travis-ci.org/lmorchard/django-valet-keys>`_ (|build-status|)
- `Latest documentation on Read The Docs <https://django-valet-keys.readthedocs.org/en/latest/>`_
  (`source <https://github.com/lmorchard/django-valet-keys/tree/master/docs>`_)
- `Task board on Huboard <http://huboard.com/lmorchard/django-valet-keys/board>`_
  (`source <https://github.com/lmorchard/django-valet-keys/issues>`_)

.. |build-status| image:: https://secure.travis-ci.org/lmorchard/django-valet-keys.png?branch=master
           :target: http://travis-ci.org/lmorchard/django-valet-keys

.. vim:set tw=78 ai fo+=n fo-=l ft=rst:
